@@ -349,9 +349,12 @@ class DownloadManager(object):
         except download_util.PathException as e:
             raise UsageError(str(e))
 
-    def get_target_download_url(self, target, **kwargs):
-        return parse_linked_bundle_url(self._get_target_path(target)).bundle_path_download_url(
-            **kwargs
+    def get_target_bypass_url(self, target, **kwargs):
+        """
+        Get SAS url with read permission. Used for bypass server downloading from Azure blob storage.
+        """
+        return parse_linked_bundle_url(self._get_target_path(target)).bundle_path_bypass_url(
+            permission='r', **kwargs
         )
 
     def _send_read_message(self, worker, response_socket_id, target, read_args):
