@@ -8,7 +8,7 @@ from marshmallow import Schema as PlainSchema, ValidationError, validate, valida
 from marshmallow_jsonapi import Schema, fields
 from marshmallow.fields import Field
 
-from codalab.common import UsageError
+from codalab.common import UsageError, NotFoundError
 from codalab.bundles import BUNDLE_SUBCLASSES
 from codalab.lib.bundle_action import BundleAction
 from codalab.lib.spec_util import SUB_PATH_REGEX, NAME_REGEX, UUID_REGEX
@@ -155,11 +155,19 @@ class BundleDependencySchema(PlainSchema):
     parent_uuid = fields.String(validate=validate_uuid)
     parent_path = fields.String(missing="")
     parent_name = fields.Method('get_parent_name', dump_only=True)  # for convenience
+    parent_state = fields.Method('get_parent_state', dump_only=True)  # for convenience
 
     def get_parent_name(self, dep):
         uuid = dep['parent_uuid']
         return local.model.get_bundle_names([uuid]).get(uuid)
 
+    def get_parent_state(self, dep):
+        uuid = dep['parent_uuid']
+        try:
+            return local.model.get_bundle_state(uuid)
+        except NotFoundError:
+            return None
+
 
 class BundlePermissionSchema(Schema):
     id = CompatibleInteger(as_string=True, dump_only=True)
